summaryrefslogtreecommitdiffstats
path: root/tests/ui/resolve/issue-3021-c.rs
diff options
context:
space:
mode:
Diffstat (limited to 'tests/ui/resolve/issue-3021-c.rs')
-rw-r--r--tests/ui/resolve/issue-3021-c.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/ui/resolve/issue-3021-c.rs b/tests/ui/resolve/issue-3021-c.rs
index 94ed1fdf7..bd21d1244 100644
--- a/tests/ui/resolve/issue-3021-c.rs
+++ b/tests/ui/resolve/issue-3021-c.rs
@@ -1,8 +1,8 @@
fn siphash<T>() {
trait U {
- fn g(&self, x: T) -> T; //~ ERROR can't use generic parameters from outer function
- //~^ ERROR can't use generic parameters from outer function
+ fn g(&self, x: T) -> T; //~ ERROR can't use generic parameters from outer item
+ //~^ ERROR can't use generic parameters from outer item
}
}